@@ -1,6 +1,4 @@
 """
-Copyright 2021 Yutong Sean
-
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
@@ -14,7 +12,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 from thbase.hbase.ttypes import TTableName
-from thbase.util.bytes import to_bytes
+from thbase.util.bytes import to_bytes, to_str
 
 __all__ = ['executor', 'handlers', 'type_check', 'check_none', 'str_to_tablename']
 
@@ -43,7 +41,6 @@ def str_to_tablename(name):
         raise RuntimeError("Get table name with wrong format.")
 
 
-def tablename_to_str(table):
-    type_check(table, TTableName)
-    name = DELIMITER.join()
-
+def tablename_to_str(table_name):
+    type_check(table_name, TTableName)
+    return DELIMITER.join([to_str(table_name.ns), to_str(table_name.qualifier)])
